Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EventAction ¶
type EventAction struct {
// save the full resource object when the event happens
SaveFullObject bool `json:"saveFullObject,omitempty"`
// save the google cmp string or not
SaveCmp bool `json:"saveCmp,omitempty"`
// save the json patch result of the diff or not
SaveJsonPatch bool `json:"saveJsonPatch,omitempty"`
}
type EventRule ¶
type EventRule struct {
Namespaces []string `json:"namespaces,omitempty"`
ExcludedNamespaces []string `json:"excludedNamespaces,omitempty"`
}
func (EventRule) Match ¶
func (er EventRule) Match(unstr *unstructured.Unstructured) bool
type KubeTrackConfiguration ¶
type KubeTrackConfiguration struct {
metav1.TypeMeta `json:",inline"`
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
// +optional
Cluster string `json:"cluster,omitempty"`
// +optional
Rules []Rule `json:"rules,omitempty" protobuf:"bytes,2,opt,name=rules"`
Events EventRule `json:"events,omitempty"`
// +optional
Output []Output `json:"output"`
}
type ObjectSelector ¶
type Output ¶
type Output struct {
Log *OutputLog
Mysql *OutputMysql
Postgres *OutputPostgres
}
type OutputMysql ¶
type OutputPostgres ¶
type Rule ¶
type Rule struct {
ObjectSelector
// the fields you cares about
CareFields []Field `json:"careFields,omitempty"`
OnCreate EventAction `json:"onCreate,omitempty"`
OnDelete EventAction `json:"onDelete,omitempty"`
OnUpdate EventAction `json:"onUpdate,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.